Struct htsget_lambda::Route

source ·
pub struct Route { /* private fields */ }
A request route, with a method, endpoint and route type.

Implementations

source

impl Route

source

pub fn new( method: HtsgetMethod, endpoint: Endpoint, route_type: RouteType ) -> Self

source

pub fn get_route( method: &Method, uri: &Uri ) -> Result<Self, Result<Response<Body>>>

Gets the Route if the request is valid, otherwise returns an error with a response.

source

pub fn method(&self) -> HtsgetMethod

source

pub fn endpoint(&self) -> &Endpoint

source

pub fn route_type(&self) -> &RouteType